# AstrBot Star

Starting from version `3.4.0`, AstrBot renamed plugins to `Star`. AstrBot is a highly modular project, and plugins leverage this modularity to implement various functionalities.

Use `/plugin` to view all plugins. You can also manage installed plugins in the admin panel.

If you want to develop your own plugin, see [AstrBot Plugin Development Guide](/en/dev/star/plugin-new).
